@@ -14,7 +14,9 @@ library(viridis) # viridis for color palettes
 library(tidyverse) # for data wrangling
 
 ## ----load-data, include=FALSE-------------------------------------------------
-# if you don't have the most recent version of BGmisc, you may need to install it first as a stop-gap I've added the data loading here
+# if you don't have the most recent version of BGmisc, 
+# you may need to install it first. 
+# As a stop-gap I've added the data loading here
 data("potter") # load example data from BGmisc
 # if (!"twinID" %in% names(potter)) {
 # Add twinID and zygosity columns for demonstration purposes
@@ -47,9 +49,10 @@ ggPedigree(
   config = list(
     code_male = 1, # Here, 1 = male, 0 = female
     sex_color_include = FALSE,
+    segment_linewidth = .75,
     point_size = 5,
-    outline_multiplier = 1.15,
-    line_width = 2.5,
+    outline_multiplier = 1.5,
+    # outline_additional_size = -1,
     sex_shape_female = "💸",
     sex_shape_male = "🖤",
     segment_spouse_color = viridis_pal()(5)[1],
@@ -58,8 +61,8 @@ ggPedigree(
     segment_offspring_color = viridis_pal()(5)[4],
     segment_mz_color = viridis_pal()(5)[5],
     #   segment_linetype = 3,
-    outline_include = TRUE,
-    outline_color = "grey" # viridis_pal()(5)[5]
+    outline_include = FALSE,
+    outline_color = "grey"
   )
 )
 
@@ -68,7 +71,7 @@ ggPedigree(potter,
   famID = "famID",
   personID = "personID"
 ) +
-  theme_bw(base_size = 12)
+  theme_bw(base_size = 12) + scale_colour_brewer(palette = "Set2")
 
 ## -----------------------------------------------------------------------------
 ggPedigree(
@@ -76,12 +79,12 @@ ggPedigree(
   famID = "famID",
   personID = "personID",
   config = list(
-    label_col = "name",
+    label_column = "first_name",
     sex_color_palette = c("pink", "blue"),
-    label_text_angle = -45,
-    label_nudge_y = -.25,
+    label_text_angle = -35,
+    label_nudge_y = .215,
     label_nudge_x = 0.45,
-    label_method = "geom_text",
+    label_method = "geom_text", # "ggrepel", #
     #   sex_color_palette = c("black", "black"),
     sex_color_include = TRUE
   )
@@ -112,14 +115,20 @@ ggPedigree(
   famID = "famID",
   personID = "ID",
   status_column = "affected",
+  overlay_column = NULL,
   config = list(
     code_male = 0,
-    sex_color_include = FALSE,
+    sex_color_include = TRUE,
+    status_include = TRUE,
+    overlay_include = FALSE,
     status_code_affected = TRUE,
     status_code_unaffected = FALSE,
     status_label_affected = "Infected",
     status_label_unaffected = "Not infected",
-    status_legend_title = "Status"
+    status_legend_title = "Status",
+    focal_fill_include = FALSE,
+    status_shape_affected = 4, # "🦠"  # virus shape
+    status_legend_show = TRUE
   )
 )
 
@@ -164,7 +173,8 @@ ggPedigree(potter,
     focal_fill_n_breaks = NULL,
     focal_fill_legend_title = "Genetic Relatives \nof Harry Potter",
     # "additive",
-    sex_color_include = FALSE
+    sex_color_include = FALSE,
+    sex_legend_show = FALSE
   ) # highlight Harry Potter
   # config  = list(segment_mz_color = NA) # color for monozygotic twins
 )
@@ -185,7 +195,8 @@ m1 <- ggPedigree(potter,
     focal_fill_n_breaks = 19,
     focal_fill_legend_show = FALSE,
     focal_fill_legend_title = "Mitochondrial Relatives \nof Harry Potter",
-    sex_color_include = FALSE
+    sex_color_include = FALSE,
+    label_text_size = 3
   ) # highlight Harry Potter
   # config  = list(segment_mz_color = NA) # color for monozygotic twins
 ) + ggplot2::guides(shape = "none")
@@ -204,7 +215,8 @@ m2 <- ggPedigree(potter,
     focal_fill_n_breaks = 19,
     focal_fill_legend_show = FALSE,
     focal_fill_legend_title = "Mitochondrial Relatives \nof Ginny Weasley",
-    sex_color_include = FALSE
+    sex_color_include = FALSE,
+    label_text_size = 3
   ) # highlight Harry Potter
   # config  = list(segment_mz_color = NA) # color for monozygotic twins
 ) + ggplot2::guides(shape = "none")
@@ -253,7 +265,8 @@ p +
     axis.ticks.y     = element_blank(),
     axis.title.x     = element_blank(),
     axis.title.y     = element_blank()
-  ) + scale_color_viridis(
+    ) + 
+  scale_color_viridis(
     option = "mako",
     discrete = TRUE,
     labels = c("Female", "Male", "Unknown")
