@@ -8,7 +8,6 @@ test_that("calculateConnections returns expected columns and structure", {
   )
 
   ped <- calculateCoordinates(ped,
-    code_male = "M",
     personID = "personID",
     momID = "momID",
     dadID = "dadID",
@@ -16,22 +15,68 @@ test_that("calculateConnections returns expected columns and structure", {
     config = list(
       ped_align = TRUE,
       ped_packed = TRUE,
-      return_midparent = TRUE
+      return_mid_parent = TRUE,
+      code_male = "M"
     )
   )
 
-  conn_out <- calculateConnections(ped, config = list(return_midparent = TRUE))
+  conn_out <- calculateConnections(ped, config = list(return_mid_parent = TRUE))
   conns <- conn_out$connections
 
   expect_true(is.data.frame(conns))
   expect_true(all(c(
     "personID", "x_pos", "y_pos", "momID", "dadID", "spouseID",
     "x_mom", "y_mom", "x_dad", "y_dad", "x_spouse", "y_spouse",
-    "x_fam", "y_fam", "x_midparent", "y_midparent", "x_mid_spouse", "y_mid_spouse",
+    "x_fam", "y_fam", "x_mid_parent", "y_mid_parent", "x_mid_spouse", "y_mid_spouse",
     "x_mid_sib", "y_mid_sib"
   ) %in% names(conns)))
+
+  expect_equal(class(conns$personID), "character")
+  expect_equal(class(conns$momID), "character")
+  expect_equal(class(conns$dadID), "character")
+  expect_equal(class(conns$spouseID), "character")
 })
 
+test_that("calculateConnections returns expected columns and structure with no spouses", {
+  ped <- data.frame(
+    personID = c("A", "B", "C", "D", "X"),
+    momID = c(NA, "A", "A", "C", NA),
+    dadID = c(NA, "X", "X", "B", NA),
+    #   spouseID = c("X", "C", "B", NA, "A"),
+    sex = c("F", "M", "F", "F", "M")
+  )
+
+  ped <- calculateCoordinates(ped,
+    personID = "personID",
+    momID = "momID",
+    dadID = "dadID",
+    #  spouseID = "spouseID",
+    config = list(
+      ped_align = TRUE,
+      ped_packed = TRUE,
+      return_mid_parent = TRUE,
+      code_male = "M"
+    )
+  )
+
+  conn_out <- calculateConnections(ped, config = list(return_mid_parent = TRUE))
+  conns <- conn_out$connections
+
+  expect_true(is.data.frame(conns))
+  expect_true(all(c(
+    "personID", "x_pos", "y_pos", "momID", "dadID", "spouseID",
+    "x_mom", "y_mom", "x_dad", "y_dad", "x_spouse", "y_spouse",
+    "x_fam", "y_fam", "x_mid_parent", "y_mid_parent", "x_mid_spouse", "y_mid_spouse",
+    "x_mid_sib", "y_mid_sib"
+  ) %in% names(conns)))
+
+  expect_equal(class(conns$personID), "character")
+  expect_equal(class(conns$momID), "character")
+  expect_equal(class(conns$dadID), "character")
+  expect_equal(class(conns$spouseID), "character")
+})
+
+
 test_that("calculateConnections returns correct parent coordinates", {
   # A is mother of C and D; X is father of C and D
   ped <- data.frame(
@@ -44,11 +89,13 @@ test_that("calculateConnections returns correct parent coordinates", {
   )
 
   ped <- calculateCoordinates(ped,
-    code_male = "M",
     personID = "personID",
     momID = "momID",
     dadID = "dadID",
-    spouseID = "spouseID"
+    spouseID = "spouseID",
+    config = list(
+      code_male = "M"
+    )
   )
   conn_out <- calculateConnections(ped)
   conns <- conn_out$connections
@@ -64,7 +111,7 @@ test_that("calculateConnections returns correct parent coordinates", {
   expect_equal(C_row$y_dad, X_coords$y_pos)
 })
 
-test_that("midparent coordinates are correct", {
+test_that("mid_parent coordinates are correct", {
   ped <- data.frame(
     personID = c("A", "B", "C"),
     momID = c(NA, NA, "A"),
@@ -74,11 +121,11 @@ test_that("midparent coordinates are correct", {
   )
 
   ped <- calculateCoordinates(ped,
-    code_male = "M",
     personID = "personID",
     momID = "momID",
     dadID = "dadID",
-    spouseID = "spouseID"
+    spouseID = "spouseID",
+    config = list(code_male = "M")
   )
   conn_out <- calculateConnections(ped)
   conns <- conn_out$connections
@@ -183,7 +230,7 @@ test_that("calculateConnections computes parental coordinates correctly", {
   expect_equal(C$y_dad, 1)
 })
 
-test_that("calculateConnections computes midparent as average of mom/dad", {
+test_that("calculateConnections computes mid_parent as average of mom/dad", {
   ped <- data.frame(
     personID = c("A", "B", "C"),
     momID = c(NA, NA, "A"),
@@ -538,7 +585,9 @@ test_that("buildSpouseSegments with use_hash=TRUE handles unmatched parent IDs",
     stringsAsFactors = FALSE
   )
 
-  result <- buildSpouseSegments(ped, connections_for_FOO, use_hash = TRUE)
+  result <- buildSpouseSegments(ped, connections_for_FOO,
+    use_hash = TRUE
+  )
 
   expect_true(is.data.frame(result))
   expect_equal(nrow(result), 2)
